# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🎨 Fix DecimalField | [4](https://github.com/laminlabs/omop/pull/4) | [sunnyosun](https://github.com/sunnyosun) | 2024-09-16 |
♻️ Fix CI | [3](https://github.com/laminlabs/omop/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2024-09-16 |
🍱 Add test data | [2](https://github.com/laminlabs/omop/pull/2) | [falexwolf](https://github.com/falexwolf) | 2024-05-08 |
